Struct trees::linked::fully::tree::Tree [−][src]
pub struct Tree<T> { /* fields omitted */ }A non-nullable tree
Methods
impl<T> Tree<T>[src]
impl<T> Tree<T>pub fn new(data: T) -> Self[src]
pub fn new(data: T) -> SelfCreates a Tree with given data on heap.
pub fn root(&self) -> &Node<T>[src]
pub fn root(&self) -> &Node<T>pub fn root_mut(&mut self) -> &mut Node<T>[src]
pub fn root_mut(&mut self) -> &mut Node<T>pub fn abandon(&mut self) -> Forest<T>[src]
pub fn abandon(&mut self) -> Forest<T>Removes and returns the given Tree's children.
Examples
use trees::linked::fully::tr; let mut tree = tr(0) /tr(1)/tr(2); assert_eq!( tree.abandon().to_string(), "( 1 2 )" ); assert_eq!( tree, tr(0) );
pub fn into_bfs(self) -> BfsTree<Splitted<IntoIter<T>>>[src]
pub fn into_bfs(self) -> BfsTree<Splitted<IntoIter<T>>>Provides a forward iterator with owned data in a breadth-first manner
Examples
use trees::{bfs,Size}; use trees::linked::fully::tr; let tree = tr(0) /( tr(1)/tr(2)/tr(3) ) /( tr(4)/tr(5)/tr(6) ); let visits = tree.into_bfs().iter.collect::<Vec<_>>(); assert_eq!( visits, vec![ bfs::Visit{ data: 0, size: Size{ degree: 2, node_cnt: 7 }}, bfs::Visit{ data: 1, size: Size{ degree: 2, node_cnt: 3 }}, bfs::Visit{ data: 4, size: Size{ degree: 2, node_cnt: 3 }}, bfs::Visit{ data: 2, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: 3, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: 5, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: 6, size: Size{ degree: 0, node_cnt: 1 }}, ]);
Methods from Deref<Target = Node<T>>
pub fn is_leaf(&self) -> bool[src]
pub fn is_leaf(&self) -> boolpub fn degree(&self) -> usize[src]
pub fn degree(&self) -> usizeReturns the number of subtrees in Forest.
Examples
use trees::linked::fully::tr; let tree = tr(0) /( tr(1)/tr(2)/tr(3) ) /( tr(4)/tr(5)/tr(6) ); assert_eq!( tree.degree(), 2 );
pub fn node_count(&self) -> usize[src]
pub fn node_count(&self) -> usizeReturns the number of all subnodes in Forest.
Examples
use trees::linked::fully::tr; let tree = tr(0) /( tr(1)/tr(2)/tr(3) ) /( tr(4)/tr(5)/tr(6) ); assert_eq!( tree.node_count(), 7 );
pub fn first(&self) -> Option<&Node<T>>[src]
pub fn first(&self) -> Option<&Node<T>>Returns the first child of the forest, or None if it is empty.
pub fn forest(&self) -> &Forest<T>[src]
pub fn forest(&self) -> &Forest<T>Returns the given Tree's children as a borrowed Forest.
Examples
use trees::linked::fully::tr; let mut tree = tr(0) /tr(1)/tr(2); assert_eq!( tree.forest().to_string(), "( 1 2 )" );
pub fn forest_mut(&mut self) -> &mut Forest<T>[src]
pub fn forest_mut(&mut self) -> &mut Forest<T>Returns the given Tree's children as a mutable borrowed Forest.
Examples
use trees::linked::fully::tr; let mut tree = tr(0) /tr(1)/tr(2); for child in tree.forest_mut().iter_mut() { child.data *= 10; } assert_eq!( tree.to_string(), "0( 10 20 )" );
pub fn first_mut(&mut self) -> Option<&mut Node<T>>[src]
pub fn first_mut(&mut self) -> Option<&mut Node<T>>Returns a mutable pointer to the first child of the forest, or None if it is empty.
pub fn last(&self) -> Option<&Node<T>>[src]
pub fn last(&self) -> Option<&Node<T>>Returns the last child of the forest, or None if it is empty.
pub fn last_mut(&mut self) -> Option<&mut Node<T>>[src]
pub fn last_mut(&mut self) -> Option<&mut Node<T>>Returns a mutable pointer to the last child of the forest, or None if it is empty.
pub fn parent(&self) -> Option<&Node<T>>[src]
pub fn parent(&self) -> Option<&Node<T>>Returns the parent node of this node, or None if it is a root node.
pub fn push_front(&mut self, tree: Tree<T>)[src]
pub fn push_front(&mut self, tree: Tree<T>)Adds the tree as the first child.
Examples
use trees::linked::fully::tr; let mut tree = tr(0); tree.push_front( tr(1) ); assert_eq!( tree.to_string(), "0( 1 )" ); tree.push_front( tr(2) ); assert_eq!( tree.to_string(), "0( 2 1 )" );
pub fn push_back(&mut self, tree: Tree<T>)[src]
pub fn push_back(&mut self, tree: Tree<T>)Add the tree as the last child
Examples
use trees::linked::fully::tr; let mut tree = tr(0); tree.push_back( tr(1) ); assert_eq!( tree.to_string(), "0( 1 )" ); tree.push_back( tr(2) ); assert_eq!( tree.to_string(), "0( 1 2 )" );
pub fn pop_front(&mut self) -> Option<Tree<T>>[src]
pub fn pop_front(&mut self) -> Option<Tree<T>>Remove and return the first child
Examples
use trees::linked::fully::tr; let mut tree = tr(0) /tr(1)/tr(2); assert_eq!( tree.pop_front(), Some( tr(1) )); assert_eq!( tree.to_string(), "0( 2 )" ); assert_eq!( tree.pop_front(), Some( tr(2) )); assert_eq!( tree.to_string(), "0" );
pub fn pop_back(&mut self) -> Option<Tree<T>>[src]
pub fn pop_back(&mut self) -> Option<Tree<T>>Remove and return the last child
Examples
use trees::linked::fully::tr; let mut tree = tr(0) /tr(1)/tr(2); assert_eq!( tree.pop_back(), Some( tr(2) )); assert_eq!( tree.to_string(), "0( 1 )" ); assert_eq!( tree.pop_back(), Some( tr(1) )); assert_eq!( tree.to_string(), "0" );
pub fn prepend(&mut self, forest: Forest<T>)[src]
pub fn prepend(&mut self, forest: Forest<T>)Add all the forest's trees at front of children list
Examples
use trees::linked::fully::tr; let mut tree = tr(0); tree.prepend( -tr(1)-tr(2) ); assert_eq!( tree.to_string(), "0( 1 2 )" ); tree.prepend( -tr(3)-tr(4) ); assert_eq!( tree.to_string(), "0( 3 4 1 2 )" );
pub fn append(&mut self, forest: Forest<T>)[src]
pub fn append(&mut self, forest: Forest<T>)Add all the forest's trees at back of children list
Examples
use trees::linked::fully::tr; let mut tree = tr(0); tree.append( -tr(1)-tr(2) ); assert_eq!( tree.to_string(), "0( 1 2 )" ); tree.append( -tr(3)-tr(4) ); assert_eq!( tree.to_string(), "0( 1 2 3 4 )" );
ⓘImportant traits for Iter<'a, T>pub fn iter<'a, 's: 'a>(&'s self) -> Iter<'a, T>[src]
pub fn iter<'a, 's: 'a>(&'s self) -> Iter<'a, T>Provides a forward iterator over child Nodes
Examples
use trees::linked::fully::tr; let tree = tr(0); assert_eq!( tree.iter().next(), None ); let tree = tr(0) /tr(1)/tr(2); let mut iter = tree.iter(); assert_eq!( iter.next(), Some( tr(1).root() )); assert_eq!( iter.next(), Some( tr(2).root() )); assert_eq!( iter.next(), None ); assert_eq!( iter.next(), None );
ⓘImportant traits for Iter<'a, T>pub fn children<'a, 's: 'a>(&'s self) -> Iter<'a, T>[src]
pub fn children<'a, 's: 'a>(&'s self) -> Iter<'a, T>: please use iter instead
ⓘImportant traits for IterMut<'a, T>pub fn iter_mut<'a, 's: 'a>(&'s mut self) -> IterMut<'a, T>[src]
pub fn iter_mut<'a, 's: 'a>(&'s mut self) -> IterMut<'a, T>Provides a forward iterator over child Nodes with mutable references.
Examples
use trees::linked::fully::tr; let mut tree = tr(0); assert_eq!( tree.iter_mut().next(), None ); let mut tree = tr(0) /tr(1)/tr(2); for child in tree.iter_mut() { child.data *= 10; } assert_eq!( tree.to_string(), "0( 10 20 )" );
ⓘImportant traits for IterMut<'a, T>pub fn children_mut<'a, 's: 'a>(&'s mut self) -> IterMut<'a, T>[src]
pub fn children_mut<'a, 's: 'a>(&'s mut self) -> IterMut<'a, T>: please use iter_mut instead
ⓘImportant traits for OntoIter<'a, T>pub fn onto_iter<'a, 's: 'a>(&'s mut self) -> OntoIter<'a, T>[src]
pub fn onto_iter<'a, 's: 'a>(&'s mut self) -> OntoIter<'a, T>Provide an iterator over Node's Subnodes for insert/remove at any position.
See Subnode's document for more.
pub fn bfs(&self) -> BfsTree<Splitted<Iter<T>>>[src]
pub fn bfs(&self) -> BfsTree<Splitted<Iter<T>>>Provides a forward iterator in a breadth-first manner
Examples
use trees::{bfs,Size}; use trees::linked::fully::tr; let tree = tr(0) /( tr(1)/tr(2)/tr(3) ) /( tr(4)/tr(5)/tr(6) ); let visits = tree.root().bfs().iter.collect::<Vec<_>>(); assert_eq!( visits, vec![ bfs::Visit{ data: &0, size: Size{ degree: 2, node_cnt: 7 }}, bfs::Visit{ data: &1, size: Size{ degree: 2, node_cnt: 3 }}, bfs::Visit{ data: &4, size: Size{ degree: 2, node_cnt: 3 }}, bfs::Visit{ data: &2, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: &3, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: &5, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: &6, size: Size{ degree: 0, node_cnt: 1 }}, ]);
pub fn bfs_mut(&mut self) -> BfsTree<Splitted<IterMut<T>>>[src]
pub fn bfs_mut(&mut self) -> BfsTree<Splitted<IterMut<T>>>Provides a forward iterator with mutable references in a breadth-first manner
Examples
use trees::{bfs,Size}; use trees::linked::fully::tr; let mut tree = tr(0) /( tr(1)/tr(2)/tr(3) ) /( tr(4)/tr(5)/tr(6) ); let visits = tree.root_mut().bfs_mut().iter.collect::<Vec<_>>(); assert_eq!( visits, vec![ bfs::Visit{ data: &mut 0, size: Size{ degree: 2, node_cnt: 7 }}, bfs::Visit{ data: &mut 1, size: Size{ degree: 2, node_cnt: 3 }}, bfs::Visit{ data: &mut 4, size: Size{ degree: 2, node_cnt: 3 }}, bfs::Visit{ data: &mut 2, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: &mut 3, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: &mut 5, size: Size{ degree: 0, node_cnt: 1 }}, bfs::Visit{ data: &mut 6, size: Size{ degree: 0, node_cnt: 1 }}, ]);